Viewer for the monzo API
=======================================

Installation
---------------------------------------

To install carry out the following steps

.. code-block:: bash

    pip install nonzo-viewer
    start
